import jwt from "jsonwebtoken"
import errors from "../errors"
import jwtVerifyCatch from "../jwtVerifyCatch"
import sendError, { API } from "./sendError"
import { IdToken, RawToken } from "./createTokenDB"

async function checkTokenIsValid(
  context: API,
  rawToken: RawToken,
  next: (token: IdToken) => void
) {
  const { value, type } = rawToken

  // Verify the token and get the payload
  let data: string | jwt.JwtPayload
  try {
    data = jwt.verify(value, process.env.ACCESS_TOKEN_SECRET as string)
  } catch (err: any) {
    // Deal with the problem in more detail
    return sendError(context, jwtVerifyCatch(type, err))
  }
  // Making sure the token data is not a string (because it should be an object)
  if (typeof data === "string")
    return sendError(context, errors.tokenWasString(type, value))

  return next({ id: data.id, type })
}

export default checkTokenIsValid
