import prisma from "../../prisma"
import { Token } from "@prisma/client"
import errors from "../errors"
import sendError, { API } from "./sendError"
import { IdToken } from "./createTokenDB"

async function getTokenDB(
  context: API,
  token: IdToken,
  next: (tokenDB: Token) => void
) {
  const { id, type } = token
  // Find refresh token in DB
  const tokenDB = await prisma.token.findUnique({
    where: {
      id,
    },
  })
  if (!tokenDB) return sendError(context, errors.tokenNotFound(type))

  if (tokenDB.used) return sendError(context, errors.tokenUsed)

  await prisma.token.update({
    where: {
      id,
    },
    data: {
      used: true,
    },
  })

  // await logging('Old token has been invalidated.', ['debug'], req)

  return next(tokenDB)
}

export default getTokenDB
