import { TokenType } from "@prisma/client"

export interface rejectionError {
  rejected?: boolean
  message: string
  statusCode: number
  solved: boolean
}
export interface rejectionErrors {
  [key: string]: rejectionError
}

const rejectionErrors = {
  noCookie: {
    rejected: true,
    message: "Unauthorized. No cookie.",
    statusCode: 401,
    solved: true,
  },
  noBody: {
    rejected: true,
    message: "Unauthorized. No Body.",
    statusCode: 401,
    solved: true,
  },
  noUsername: {
    rejected: true,
    message: "No username in request body!",
    statusCode: 401,
    solved: true,
  },
  noPassword: {
    rejected: true,
    message: "No password in request body!",
    statusCode: 401,
    solved: true,
  },
  wrongPassword: {
    message: "Passwords do not match!",
    statusCode: 401,
    solved: true,
  },
  playerNotFound: {
    message: "Player name not found in DB!",
    statusCode: 401,
    solved: false,
  },
  tokenWasString(tokenType: TokenType, tokenValue: string) {
    return {
      rejected: true,
      message: `${tokenType}-Token data was a string. Token: ${tokenValue}`,
      statusCode: 401,
      solved: false,
    }
  },
  tokenNotFound(tokenType: TokenType) {
    return {
      rejected: true,
      message: `${tokenType}-Token not found in DB!`,
      statusCode: 401,
      solved: true,
      type: "warn",
    }
  },
  tokenUsed: {
    rejected: true,
    message: "DBToken was already used!",
    statusCode: 401,
    solved: true,
  },
  noToken(tokenType: TokenType) {
    return {
      rejected: true,
      message: `Unauthorized. No ${tokenType}-Token.`,
      statusCode: 401,
      solved: true,
    }
  },
}
export default rejectionErrors
