import { NextApiRequest, NextApiResponse } from "next"
import { Logging } from "../../lib/backend/logging"
import { Token } from "@prisma/client"
import sendError from "../../lib/backend/components/sendError"
import getTokenFromCookie from "../../lib/backend/components/getTokenFromCookie"
import checkTokenIsValid from "../../lib/backend/components/checkTokenIsValid"
import getTokenDB from "../../lib/backend/components/getTokenDB"
import getPlayerByIdDB from "../../lib/backend/components/getPlayerByIdDB"
import createTokenDB, {
  RawToken,
} from "../../lib/backend/components/createTokenDB"
import sendResponse from "../../lib/backend/components/sendResponse"

interface Data {
  token: string
}

export default async function auth(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  getTokenFromCookie(context, (refreshToken) => {
    checkTokenIsValid(context, refreshToken, (token) => {
      getTokenDB(context, token, (tokenDB) => {
        getPlayerByIdDB(context, tokenDB, (player) => {
          createTokenDB(player, "ACCESS", (newToken, newTokenDB) => {
            sendResponse(context, authResponse(newToken, newTokenDB, tokenDB))
          })
        })
      })
    })
  }).catch((err) => sendError(context, err))
}

function authResponse(newToken: RawToken, newTokenDB: Token, tokenDB: Token) {
  // Successfull response
  return {
    message: `Access-Token generated: ${newTokenDB.id} with Refreshtoken-Token: ${tokenDB.id}`,
    body: { token: newToken.value },
    type: ["debug", "info.cyan"] as Logging[],
  }
}
