import { NextApiRequest, NextApiResponse } from "next"
import createPlayerDB from "../../lib/backend/components/createPlayerDB"
import sendError from "../../lib/backend/components/sendError"
import sendResponse from "../../lib/backend/components/sendResponse"
import { Logging } from "../../lib/backend/logging"
import { Player } from "@prisma/client"
import getUserFromBody from "../../lib/backend/components/getUserFromBody"

interface Data {
  registered: boolean
}

export default async function register(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  return getUserFromBody(context, (username, password) =>
    createPlayerDB(username, password, (player) => {
      sendResponse(context, registerResponse(player))
    }).catch((err) => sendError(context, err))
  )
}

function registerResponse<T>(player: Player) {
  // Successfull response
  return {
    message: "Player created : " + player.id,
    statusCode: 201,
    body: { registered: true },
    type: ["debug", "info.cyan"] as Logging[],
  }
}
